SELECT element.id AS parent_id,
       element.name AS parent_name,
       elementtype.display_name AS parent_type,
       element.id AS id,
       element.name AS name,
       elementtype.display_name AS type_name,
       element.image_id AS image_id,
       element.polygon::bytea AS polygon,
       element.worker_version_id AS worker_version_id
FROM documents_element element
INNER JOIN documents_elementtype elementtype ON (elementtype.id = element.type_id)
WHERE element.corpus_id = '{corpus_id}'::uuid
    AND elementtype.indexable
ORDER BY element.id ;

WITH parent AS
    (SELECT element.id AS parent_id,
            element.name AS parent_name,
            elementtype.display_name AS parent_type,
            element.id AS id,
            element.name AS name,
            elementtype.display_name AS type_name,
            element.image_id AS image_id,
            element.polygon::bytea AS polygon,
            element.worker_version_id AS worker_version_id
     FROM documents_element element
     INNER JOIN documents_elementtype elementtype ON (elementtype.id = element.type_id)
     WHERE element.corpus_id = '{corpus_id}'::uuid
         AND elementtype.indexable
     ORDER BY element.id)
SELECT parent_id,
       parent_name,
       parent_type,
       element.id as id,
       element.name as name,
       elementtype.display_name as type_name,
       element.image_id AS image_id,
       element.polygon::bytea AS polygon,
       element.worker_version_id AS worker_version_id
FROM
    (SELECT *
     FROM parent
     LIMIT 10000
     OFFSET 0) AS parent_chunk
INNER JOIN documents_elementpath as elementpath ON (elementpath.path @ > ARRAY[parent_chunk.id])
INNER JOIN documents_element as element ON (elementpath.element_id = element.id)
INNER JOIN documents_elementtype elementtype ON (element.type_id = elementtype.id) ;

SELECT "process_workerversion"."id",
       "process_workerversion"."worker_id",
       "process_workerversion"."revision_id",
       "process_workerversion"."version",
       "process_workerversion"."configuration",
       "process_workerversion"."state",
       "process_workerversion"."gpu_usage",
       "process_workerversion"."model_usage",
       "process_workerversion"."docker_image_id",
       "process_workerversion"."docker_image_iid",
       "process_workerversion"."created",
       "process_workerversion"."updated"
FROM "process_workerversion"
WHERE "process_workerversion"."id" IN ('{worker_version_id}'::uuid);

SELECT "process_worker"."id",
       "process_worker"."name",
       "process_worker"."slug",
       "process_worker"."type_id",
       "process_worker"."repository_id",
       "process_worker"."public"
FROM "process_worker"
WHERE "process_worker"."id" IN ('{worker_id}'::uuid);

SELECT "documents_transcription"."id",
       "documents_transcription"."element_id",
       "documents_transcription"."worker_version_id",
       "documents_transcription"."worker_run_id",
       "documents_transcription"."text",
       "documents_transcription"."orientation",
       "documents_transcription"."confidence"
FROM "documents_transcription"
WHERE "documents_transcription"."element_id" IN ('{page_id}'::uuid);

SELECT "documents_classification"."id",
       "documents_classification"."element_id",
       "documents_classification"."worker_version_id",
       "documents_classification"."worker_run_id",
       "documents_classification"."moderator_id",
       "documents_classification"."ml_class_id",
       "documents_classification"."high_confidence",
       "documents_classification"."state",
       "documents_classification"."confidence"
FROM "documents_classification"
WHERE "documents_classification"."element_id" IN ('{page_id}'::uuid);

SELECT "documents_metadata"."id",
       "documents_metadata"."element_id",
       "documents_metadata"."name",
       "documents_metadata"."type",
       "documents_metadata"."value",
       "documents_metadata"."entity_id",
       "documents_metadata"."worker_version_id",
       "documents_metadata"."worker_run_id"
FROM "documents_metadata"
WHERE "documents_metadata"."element_id" IN ('{page_id}'::uuid)
ORDER BY "documents_metadata"."element_id" ASC,
         "documents_metadata"."name" ASC,
         "documents_metadata"."id" ASC;

SELECT ("documents_transcriptionentity"."transcription_id") AS "_prefetch_related_val_transcription_id",
       "documents_entity"."id",
       "documents_entity"."name",
       "documents_entity"."type_id",
       "documents_entity"."corpus_id",
       "documents_entity"."metas",
       "documents_entity"."validated",
       "documents_entity"."moderator_id",
       "documents_entity"."worker_version_id",
       "documents_entity"."worker_run_id"
FROM "documents_entity"
INNER JOIN "documents_transcriptionentity" ON ("documents_entity"."id" = "documents_transcriptionentity"."entity_id")
WHERE "documents_transcriptionentity"."transcription_id" IN ('{transcription_id}'::uuid);

SELECT "process_workerversion"."id",
       "process_workerversion"."worker_id",
       "process_workerversion"."revision_id",
       "process_workerversion"."version",
       "process_workerversion"."configuration",
       "process_workerversion"."state",
       "process_workerversion"."gpu_usage",
       "process_workerversion"."model_usage",
       "process_workerversion"."docker_image_id",
       "process_workerversion"."docker_image_iid",
       "process_workerversion"."created",
       "process_workerversion"."updated"
FROM "process_workerversion"
WHERE "process_workerversion"."id" IN ('{worker_version_id}'::uuid);

SELECT "process_worker"."id",
       "process_worker"."name",
       "process_worker"."slug",
       "process_worker"."type_id",
       "process_worker"."repository_id",
       "process_worker"."public"
FROM "process_worker"
WHERE "process_worker"."id" IN ('{worker_id}'::uuid);

SELECT "documents_entitytype"."id",
       "documents_entitytype"."name",
       "documents_entitytype"."color",
       "documents_entitytype"."corpus_id"
FROM "documents_entitytype"
WHERE "documents_entitytype"."id" IN ('{type_id}'::uuid)
